@@ -71,7 +71,7 @@ void segatex::segatex_remove_my_policy()
         os.open(remove_file);
         if(os){
                 FILE *read_fp;
-                #define SIZE_TMP 8192
+                #define SIZE_TMP 8600
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
@@ -105,7 +105,7 @@ void segatex::segatex_module_list()
         os.open(module_list_file);
         if(os){
                 FILE *read_fp;
-                #define SIZE_TMP 8192
+                #define SIZE_TMP 8600
                 char buffer[SIZE_TMP];
                 int chars_read;
                 memset(buffer, '\0', sizeof(buffer));
@@ -171,7 +171,7 @@ void segatex::segatex_write_to_my_policy()
 			if(check==0){
 				FILE *read_fp_install;
 				FILE *read_fp;
-				#define SIZE_TMP 8192
+				#define SIZE_TMP 8600
 				char buffer[SIZE_TMP];
 				int chars_read;
 				memset(buffer, '\0', sizeof(buffer));
@@ -223,7 +223,7 @@ void segatex::segatex_yum_update()
 	if(os){
 		FILE *read_fp_install;
 		FILE *read_fp;
-		#define SIZE_TMP 8192
+		#define SIZE_TMP 8600
 		char buffer[SIZE_TMP];
 		int chars_read;
 		memset(buffer, '\0', sizeof(buffer));
@@ -268,11 +268,11 @@ void segatex::segatex_audit_2_allow()
 	os.open(audit_2_allow_file);
 	if(os){
 		FILE *read_fp;
-		#define SIZE_TMP 8192
+		#define SIZE_TMP 8600
 		char buffer[SIZE_TMP];
 		int chars_read;
 		memset(buffer, '\0', sizeof(buffer));
-		read_fp = popen("audit2allow -m local -i /var/log/audit/audit.log", "r");
+		read_fp = popen("audit2allow -m local -a", "r");
 		if(read_fp != NULL){
 			chars_read = fread(buffer, sizeof(char), SIZE_TMP, read_fp);
 			while(chars_read>0){
@@ -301,7 +301,7 @@ void segatex::segatex_audit_2_why()
 	os.open(audit_2_why_file);
 	if(os){
 		FILE *read_fp;
-		#define SIZE_TMP 8192
+		#define SIZE_TMP 8600
 		char buffer[SIZE_TMP];
 		int chars_read;
 		memset(buffer, '\0', sizeof(buffer));
@@ -528,7 +528,9 @@ void segatex::segatex_show_interface()
 					const char* scontext_rev = "t_[a-z0-9_]([^:]*)?";
 					const char* tcontext = "tcontext([^[:blank:]]*)([:blank:])?";
 					const char* tcontext_rev = "t_[a-z0-9_]([^:]*)?";
-					const char* tclass = "tclass(.*)";
+					//changed in segatex2.11
+					//const char* tclass = "tclass(.*)";
+					const char* tclass = "tclass=[a-z0-9_]*";
 					const char* tclass_2 = "[a-z0-9_]([^=]*)?";
 					const char* acc = "\\{(.*)\\}";
 					const char* role = ":[a-z0-9_]*_r";
@@ -688,6 +690,7 @@ void segatex::segatex_show_interface()
 							}
 							if(regex_search(source,what,object_class_exp)){
 								object_class_pre = what[0];
+								//os_policy << object_class << endl;
 								int str_length = strlen(object_class_pre.c_str());
 								int i=str_length;
 								string str_rev="";
@@ -708,6 +711,7 @@ void segatex::segatex_show_interface()
 										str_rev_all = str_rev_all + str_rev;
 									}
 									object_class = str_rev_all;
+									//os_policy << object_class << endl;
 								}
 							}
 							if(regex_search(source,what,access_vector_exp)){
@@ -731,7 +735,8 @@ void segatex::segatex_show_interface()
 					const char* m_interface_pre = "[a-z]([^[:space:]]*):([^[:space:]]*)([:space:])?";
 					const char* m_domain_pre = "[a-z0-9_]*_t";
 					const char* m_tclass_pre = "[a-z0-9_]*_t:";
-					const char* m_objclass_pre = ":[a-z0-9_]*";
+					//changed here at segatex2.11
+					const char* m_objclass_pre = ":[a-z0-9_]*([^[:space:]]*)([:space:])?";
 					const char* m_acc = "\\{(.*)\\}";
 					const char* m_blank = "[a-z0-9_](.*)[a-z0-9_]";
 					regex m_pre_exp(m_pre);
@@ -775,12 +780,15 @@ void segatex::segatex_show_interface()
 							/*for debug*/
 							//os_policy << source_tclass_pre << endl;	
 						} 
+						//changed here at segatex2.11
 						if(regex_search(source_m,what,m_objclass_pre_exp)){
 							source_objclass_pre  = what[0];
+							int length=strlen(source_objclass_pre.c_str());
 							string blank_str="";
 							source_objclass_pre=source_objclass_pre.replace(0,1,blank_str);
+							source_objclass_pre=source_objclass_pre.replace(length - 1,1,blank_str);
 							/*for debug*/
-						//	os_policy << source_objclass_pre << endl;	
+							//os_policy << source_objclass_pre << endl;	
 						} 
 						if(regex_search(source_m,what,m_access_vector_exp)){
 							source_access_vector_pre  = what[0];
@@ -806,6 +814,8 @@ void segatex::segatex_show_interface()
 						pattern_matched.insert(pair<string, string>(source_interface_pre,source_domain_pre));
 						pattern_not_matched.insert(pair<string, string>(source_interface_pre,source_macro));
 						pattern_not_matched_objclass.insert(pair<string, string>(source_interface_pre,source_objclass_pre));
+						//forgot to check this...segatex2.11
+						//os_policy << "<" << source_objclass_pre << ":" << source_access_vector_pre << ">" << endl;
 						pattern_not_matched_access_vector.insert(pair<string, string>(source_objclass_pre,source_access_vector_pre));
 						pattern_not_matched_domain.insert(pair<string, string>(source_interface_pre,source_domain_pre));
 						pattern_not_matched_tclass.insert(pair<string, string>(source_interface_pre,source_tclass_pre));
@@ -1095,13 +1105,19 @@ void segatex::segatex_show_interface()
 							if(regex_search(objclass_interface_h_cstr,what,m_objclass_interface_h_dash_exp)){
 								objclass_interface_h = what[0];
 							}
-							objclass_interface_h=objclass_interface_h.replace(0,1,blank_str);
-							//os_policy << "objclass_interface_h" << objclass_interface_h << ":" << endl;
-							//v_tmp_objclassϡ¤ϸΥȤʤΤǡ֤줿(󥿥եäƤ)
-							//objclassѤǤʤȥᡣ
-							//Ǥϡv_matched_tmp_objclassѤߡȤv_tmp_objclass˲ä
-							v_matched_tmp_objclass.push_back(objclass_interface_h.c_str());
-							objclass_interface_h = objclass_interface_h + space_str ;
+							//os_policy << objclass_interface_h << endl;
+							//added in segatex2.11
+							string colon=":";
+							if(objclass_interface_h != colon){
+								objclass_interface_h=objclass_interface_h.replace(0,1,blank_str);
+								//os_policy << "objclass_interface_h:" << objclass_interface_h << ":" << endl;
+								//v_tmp_objclassϡ¤ϸΥȤʤΤǡ֤줿(󥿥եäƤ)
+								//objclassѤǤʤȥᡣ
+								//Ǥϡv_matched_tmp_objclassѤߡȤv_tmp_objclass˲ä
+								//added if clause segatex2.11
+								v_matched_tmp_objclass.push_back(objclass_interface_h.c_str());
+								objclass_interface_h = objclass_interface_h + space_str ;
+							}
 						}else{
 							//С2.03ɮʬʡelseˤƤʤäΤǡѤʻˤʤäƤ...
 							//С2.02ɮʬʥ٥{}ǰϤޤƤ櫓Ǥ̵
@@ -1125,12 +1141,24 @@ void segatex::segatex_show_interface()
 							if(regex_search(source_engine_str,what,m_accv_interface_h_exp)){
 								//
 								accv_interface_h = what[0];
-								string bracket_first_str="{";
-								string bracket_last_str="{";
 								accv_interface_h=accv_interface_h.replace(0,1,blank_str);
 								int length=strlen(accv_interface_h.c_str());
 								accv_interface_h=accv_interface_h.replace(length -1,1,blank_str);
+								//added in seagtex2.11{}ʧ
+								int bracket_first_position=-1;
+								int bracket_last_position=-1;
+								bracket_first_position=accv_interface_h.find("{");
+								if(bracket_first_position != -1){
+									//os_policy << bracket_first_position << "found bracket_first_str !!" << endl;	
+									accv_interface_h=accv_interface_h.replace(bracket_first_position,2,blank_str);
+								}
+								bracket_last_position=accv_interface_h.find("}");
+								if(bracket_last_position != -1){
+									//os_policy << bracket_last_position << "found bracket_last_str !!" << endl;	
+									accv_interface_h=accv_interface_h.replace(bracket_last_position,2,blank_str);
+								}
 								//os_policy << accv_interface_h << endl;	
+
 								//segatex2.05ɮʤ󡢤ޤʡ
 								regex tmp_re("[[:space:]]([^[:space:]]*)[a-z0-9_]*");
 								regex tmp_re2("[[:space:]][a-z0-9_]*_t");
@@ -1206,13 +1234,14 @@ void segatex::segatex_show_interface()
 					p_tmp_objclass_end=unique(v_tmp_objclass.begin(),v_tmp_objclass.end());
 
 					os_policy << "####################################################" << endl;
-					os_policy << "##### This file was generated by segatex2.10" << endl;
+					os_policy << "##### This file was generated by segatex2.11" << endl;
 					os_policy << "####################################################" << endl;
 					os_policy << "module my_policy_by_segatex 1.0.0;" << endl << endl;
 					os_policy << "require {" << endl;
 					string p_pattern_not_matched_objclass_pre=*v_tmp_objclass.begin();
 					for(p_tmp_objclass=v_tmp_objclass.begin(); p_tmp_objclass < p_tmp_objclass_end; p_tmp_objclass++){
 						string tmp_str= *p_tmp_objclass;
+						string v_accv_pre_str="";
 						//os_policy << "tmp_str:" << tmp_str << endl;
 						/*ǤϡޥåʤäΤȡΤȡ󥿥եäƤobjclassaccess_vectorƳФƤ*/
 						p_pattern_not_matched_access_vector=pattern_not_matched_access_vector.find(tmp_str);
@@ -1226,8 +1255,22 @@ void segatex::segatex_show_interface()
 									if(regex_search(p_pattern_not_matched_access_vector->second.c_str(),what,tmp_re3)){
 										/*⤷ʤ*/
 									}else{
-										//os_policy << p_pattern_not_matched_access_vector->second << " ";
-										v_accv.push_back(p_pattern_not_matched_access_vector->second.c_str());
+										v_accv_pre_str=p_pattern_not_matched_access_vector->second;
+										//added in seagtex2.11{}ʧ
+										int bracket_first_position=-1;
+										int bracket_last_position=-1;
+										bracket_first_position=v_accv_pre_str.find("{");
+										if(bracket_first_position != -1){
+											//os_policy << bracket_first_position << "found bracket_first_str !!" << endl;	
+											v_accv_pre_str=v_accv_pre_str.replace(bracket_first_position,2,blank_str);
+										}
+										bracket_last_position=v_accv_pre_str.find("}");
+										if(bracket_last_position != -1){
+											//os_policy << bracket_last_position << "found bracket_last_str !!" << endl;	
+											v_accv_pre_str=v_accv_pre_str.replace(bracket_last_position,2,blank_str);
+										}
+										//os_policy << v_accv_pre_str << " ";
+										v_accv.push_back(v_accv_pre_str.c_str());
 									}
 								}
 								p_pattern_not_matched_objclass_pre = p_pattern_not_matched_access_vector->first;
